/**
 * -------------------------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.
 * See License in the project root for license information.
 * -------------------------------------------------------------------------------------------
 */
import { type RequestOption, Headers } from "@microsoft/kiota-abstractions";
export declare const HeadersInspectionOptionsKey = "HeadersInspectionOptionsKey";
/**
 * Signature to define the HeadersInspectionOptions constructor parameters
 */
export interface HeadersInspectionOptionsParams {
    /**
     * whether to inspect request headers
     */
    inspectRequestHeaders?: boolean;
    /**
     * whether to inspect response headers
     */
    inspectResponseHeaders?: boolean;
}
/**
 * RequestOption
 * Options
 * Options to inspect headers
 */
export declare class HeadersInspectionOptions implements RequestOption {
    private readonly requestHeaders;
    private readonly responseHeaders;
    /**
     * Gets the request headers
     * @returns the request headers
     */
    getRequestHeaders(): Headers;
    /**
     * Gets the response headers
     * @returns the response headers
     */
    getResponseHeaders(): Headers;
    /**
     * @default false
     * whether to inspect request headers
     */
    inspectRequestHeaders: boolean;
    /**
     * @default false
     * whether to inspect response headers
     */
    inspectResponseHeaders: boolean;
    /**
     *
     * To create an instance of HeadersInspectionOptions
     * @param [options] - The headers inspection options value
     * @returns An instance of HeadersInspectionOptions
     * @example const options = new HeadersInspectionOptions({ inspectRequestHeaders: true, inspectResponseHeaders: true });
     */
    constructor(options?: Partial<HeadersInspectionOptionsParams>);
    getKey(): string;
}
//# sourceMappingURL=headersInspectionOptions.d.ts.map