/**
 * -------------------------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.
 * See License in the project root for license information.
 * -------------------------------------------------------------------------------------------
 */
import type { RequestOption } from "@microsoft/kiota-abstractions";
/**
 * Key for the url replace handler options.
 */
export declare const UrlReplaceHandlerOptionsKey = "UrlReplaceHandlerOptionsKey";
/**
 * Options for the url replace handler.
 */
export declare class UrlReplaceHandlerOptions implements RequestOption {
    private readonly _urlReplacements;
    private readonly _enabled;
    /**
     * Create a new instance of the UrlReplaceHandlerOptions class
     * @param config the configuration to apply to the url replace handler options.
     */
    constructor(config?: Partial<UrlReplaceHandlerOptionsParams>);
    /**
     * @inheritdoc
     */
    getKey(): string;
    /**
     * Returns whether the url replace handler is enabled or not.
     * @returns whether the url replace handler is enabled or not.
     */
    get enabled(): boolean;
    /**
     * Returns the url replacements combinations.
     * @returns the url replacements combinations.
     */
    get urlReplacements(): Record<string, string>;
}
/**
 * Parameters for the UrlReplaceHandlerOptions class constructor
 */
export interface UrlReplaceHandlerOptionsParams {
    urlReplacements: Record<string, string>;
    enabled: boolean;
}
//# sourceMappingURL=urlReplaceHandlerOptions.d.ts.map