/**
 * -------------------------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation.  All Rights Reserved.  Licensed under the MIT License.
 * See License in the project root for license information.
 * -------------------------------------------------------------------------------------------
 */
/**
 * Key for the url replace handler options.
 */
export const UrlReplaceHandlerOptionsKey = "UrlReplaceHandlerOptionsKey";
/**
 * Options for the url replace handler.
 */
export class UrlReplaceHandlerOptions {
    /**
     * Create a new instance of the UrlReplaceHandlerOptions class
     * @param config the configuration to apply to the url replace handler options.
     */
    constructor(config) {
        var _a, _b;
        if (config) {
            this._urlReplacements = (_a = config.urlReplacements) !== null && _a !== void 0 ? _a : {};
            this._enabled = (_b = config.enabled) !== null && _b !== void 0 ? _b : true;
        }
        else {
            this._urlReplacements = {};
            this._enabled = true;
        }
    }
    /**
     * @inheritdoc
     */
    getKey() {
        return UrlReplaceHandlerOptionsKey;
    }
    /**
     * Returns whether the url replace handler is enabled or not.
     * @returns whether the url replace handler is enabled or not.
     */
    get enabled() {
        return this._enabled;
    }
    /**
     * Returns the url replacements combinations.
     * @returns the url replacements combinations.
     */
    get urlReplacements() {
        return this._urlReplacements;
    }
}
//# sourceMappingURL=urlReplaceHandlerOptions.js.map